@@ -1,4 +1,9 @@
-from tracardi_plugin_sdk.domain.register import Plugin, Spec, MetaData, Form, FormGroup, FormField, FormComponent
+import copy
+
+from pydantic import AnyHttpUrl, HttpUrl
+
+from tracardi_plugin_sdk.domain.register import Plugin, Spec, MetaData, Form, FormGroup, FormField, FormComponent, \
+    Documentation, PortDoc
 from tracardi_plugin_sdk.action_runner import ActionRunner
 from tracardi_plugin_sdk.domain.result import Result
 from tracardi.domain.profile import Profile
@@ -46,7 +51,7 @@ class KeyCounterAction(ActionRunner):
 
         self.profile.replace(Profile(**dot.profile))
 
-        return Result(port='counts', value=counter.counts)
+        return Result(port='payload', value=payload)
 
 
 def register() -> Plugin:
@@ -57,8 +62,8 @@ def register() -> Plugin:
             module='tracardi_key_counter.plugin',
             className='KeyCounterAction',
             inputs=['payload'],
-            outputs=['counts'],
-            version="0.6.0",
+            outputs=['payload'],
+            version="0.6.0.1",
             license="MIT",
             author="Risto Kowaczewski",
             manual="key_counter_action",
@@ -92,6 +97,14 @@ def register() -> Plugin:
             type='flowNode',
             width=200,
             height=100,
+            documentation=Documentation(
+                inputs={
+                    "payload": PortDoc(desc="This port takes any JSON like object.")
+                },
+                outputs={
+                    "payload": PortDoc(desc="This port takes any JSON like object.")
+                }
+            ),
             icon='bar-chart',
             group=['Stats']
         )
